netapp_ontap.models.security_azure API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_azure`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityAzureSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityAzure object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `client_certificate: str POST`

    PKCS12 certificate used by the application to prove its identity to AKV.

    Example: PEM Cert

  `client_id: str POST`

    Application client ID of the deployed Azure application with appropriate access to an AKV.

    Example: aaaaaaaa-bbbb-aaaa-bbbb-aaaaaaaaaaaa

  `client_secret: str POST`

    Secret used by the application to prove its identity to AKV.

    Example: abcdef

  `key_vault: str POST`

    URI of the deployed AKV that is used by ONTAP for storing keys.

    Example: https://kmip-akv-keyvault.vault.azure.net/

  `oauth_host: str POST`

    Open authorization server host name.

    Example: login.microsoftonline.com

  `proxy: SecurityProxy GET POST PATCH`

    The proxy field of the security_azure.

  `tenant_id: str POST`

    Directory (tenant) ID of the deployed Azure application with appropriate access to an AKV.

    Example: zzzzzzzz-yyyy-zzzz-yyyy-zzzzzzzzzzzz

  `timeout: Size POST`

    AKV connection timeout, in seconds. The allowed range is between 0 to 30 seconds.

    Example: 25

  `verify_host: bool POST`

    Verify the identity of the AKV host name. By default, verify_host is set to true.